==> xcsoar-7.15.tar.xz: xcsoar-7.15/src/Tracking/SkyLines/Settings.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_TRACKING_SKYLINES_SETTINGS_HPP
#define XCSOAR_TRACKING_SKYLINES_SETTINGS_HPP

#include "CloudSettings.hpp"
#include "Features.hpp"
#include "util/TriState.hpp"

#ifdef HAVE_SKYLINES_TRACKING

#include <cstdint>

namespace SkyLinesTracking {

struct Settings {
  bool enabled;

  /**
   * Enable tracking while on a "roamed" connection?
   */
  bool roaming;

  /**
   * Periodically request friend traffic information?
   */
  bool traffic_enabled;

  /**
   * Periodically request near traffic information?
   */
  bool near_traffic_enabled;

  /**
   * Tracking interval in seconds.
   */
  unsigned interval;

  uint64_t key;

  CloudSettings cloud;

  void SetDefaults() {
    enabled = false;
    roaming = true;
    traffic_enabled = false;
    near_traffic_enabled = false;
    interval = 5;
    key = 0;
    cloud.SetDefaults();
  }
};

} /* namespace SkyLinesTracking */

#endif

#endif

==> xcsoar-7.25.tar.xz: xcsoar-7.25/src/Tracking/SkyLines/Settings.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2022 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#pragma once

#include "CloudSettings.hpp"
#include "Features.hpp"
#include "util/TriState.hpp"

#ifdef HAVE_SKYLINES_TRACKING

#include <cstdint>

namespace SkyLinesTracking {

struct Settings {
  bool enabled;

  /**
   * Enable tracking while on a "roamed" connection?
   */
  bool roaming;

  /**
   * Periodically request friend traffic information?
   */
  bool traffic_enabled;

  /**
   * Periodically request near traffic information?
   */
  bool near_traffic_enabled;

  /**
   * Tracking interval in seconds.
   */
  unsigned interval;

  uint64_t key;

  CloudSettings cloud;

  void SetDefaults() {
    enabled = false;
    roaming = true;
    traffic_enabled = false;
    near_traffic_enabled = false;
    interval = 5;
    key = 0;
    cloud.SetDefaults();
  }
};

} /* namespace SkyLinesTracking */

#endif
